![booklab_logo](../pictures/booklab_logo.png){ width="55" align=left }
<small markdown>**BookLab System**<br>
*(c) 2023 RENware Software Systems*
</small><br><br>


# PRVB previzualizare si testare carte


***Cuprins:***

[TOC]

***

-#NOTE: the HTTP preview server should run on a port DIFFERENT than 80 which is reserved for main application<br>
-#NOTE: `8111` port was proposed (see `810.02-System_Landscape.md` document)



![wip page](../pictures/under_maintenance.png)

-#TODO... UPCOMING...


